@@ -39,9 +39,6 @@
 #undef HAVE_XINPUT
 #undef X_SERVER
 #undef X_SERVER_PATH
-#undef X_XNEST_CMD
-#undef X_XNEST_CONFIG_OPTIONS
-#undef X_XNEST_UNSCALED_FONTPATH
 #undef X_CONFIG_OPTIONS
 #undef X_PATH
 #undef XSESSION_SHELL
